@@ -2,197 +2,9 @@ from __future__ import absolute_import, division, print_function
 import sys, os
 import iotbx.phil
 from libtbx.utils import Sorry
+import libtbx.phil
 
-master_phil = iotbx.phil.parse("""
-
-  input_files
-    .style = menu_item auto_align
-  {
-
-    map_file = None
-      .type = path
-      .help = File with CCP4-style map
-      .short_caption = Map file
-      .style = file_type:ccp4_map bold input_file
-
-    half_map_file = None
-      .type = path
-      .multiple = True
-      .short_caption = Half map
-      .style = file_type:ccp4_map bold input_file
-      .help = Half map (two should be supplied) for FSC calculation. Must \
-               have grid identical to map_file
-
-    external_map_file = None
-      .type = path
-      .short_caption = External map
-      .style = file_type:ccp4_map bold input_file
-      .help = External map to be used to scale map_file (power vs resolution\
-              will be matched)
-
-    map_coeffs_file = None
-      .type = path
-      .help = Optional file with map coefficients
-      .short_caption = Map coefficients
-      .style = bold file_type:hkl input_file process_hkl \
-        child:map_labels:map_coeffs_labels \
-        child:space_group:space_group child:unit_cell:unit_cell
-
-    map_coeffs_labels = None
-      .type = str
-      .input_size = 160
-      .help = Optional label specifying which columns of of map coefficients \
-          to use
-      .short_caption = Map coeffs label
-      .style = renderer:draw_map_arrays_widget
-
-    pdb_file = None
-      .type = path
-      .help = If a model is supplied, the map will be adjusted to \
-                maximize map-model correlation.  This can be used \
-                to improve a map in regions where no model is yet \
-                built.
-      .style = file_type:pdb input_file
-      .short_caption = Model file (optional)
-
-    ncs_file = None
-      .type = path
-      .help = File with NCS information (typically point-group NCS with \
-               the center specified). Typically in  PDB format. \
-              Can also be a .ncs_spec file from phenix. \
-              Created automatically if symmetry is specified.
-      .short_caption = NCS info file
-
-    seq_file = None
-       .type = path
-       .short_caption = Sequence file
-       .style = file_type:seq input_file
-       .help = Sequence file (unique chains only,  \
-               1-letter code, chains separated by \
-               blank line or greater-than sign.)  \
-               Can have chains that are DNA/RNA/protein and\
-               all can be present in one file.
-
-    input_weight_map_pickle_file = None
-      .type = path
-      .short_caption = Input weight map pickle file
-      .help = Weight map pickle file
-
-  }
-
-  output_files
-    .style = menu_item auto_align
-  {
-
-    shifted_map_file = shifted_map.ccp4
-      .type = str
-      .help = Input map file shifted to new origin.
-      .short_caption = Shifted map file
-      .style = new_file
-
-    sharpened_map_file = sharpened_map.ccp4
-      .type = str
-      .help = Sharpened input map file. In the same location as input map.
-      .short_caption = Sharpened map file
-      .input_size = 400
-      .style = new_file
-
-    shifted_sharpened_map_file = None
-      .type = str
-      .help = Input map file shifted to place origin at 0,0,0 and sharpened.
-      .short_caption = Shifted sharpened map file
-      .input_size = 400
-      .style = new_file
-
-    sharpened_map_coeffs_file = sharpened_map_coeffs.mtz
-      .type = str
-      .help = Sharpened input map \
-              (shifted to new origin if original origin was not 0,0,0), \
-              written out as map coefficients
-      .short_caption = Sharpened map coeffs file
-      .input_size = 400
-      .style = new_file
-
-    output_weight_map_pickle_file = weight_map_pickle_file.pkl
-       .type = path
-       .short_caption = Output weight map pickle file
-       .help = Output weight map pickle file
-       .style = new_file
-
-    output_directory =  None
-      .type = path
-      .help = Directory where output files are to be written \
-                applied.
-      .short_caption = Output directory
-      .style = new_file directory
-
-  }
-
-  crystal_info
-    .style = menu_item auto_align
-  {
-
-     is_crystal = None
-       .type = bool
-       .short_caption = Is a crystal
-       .help = Defines whether this is a crystal (or cryo-EM).\
-                Default is True if use_sg_symmetry=True and False otherwise.
-
-     resolution = None
-       .type = float
-       .short_caption = Resolution
-       .help = Optional nominal resolution of the map.
-       .style = resolution
-
-
-     solvent_content = None
-       .type = float
-       .help = Optional solvent fraction of the cell.
-       .short_caption = Solvent content
-
-     solvent_content_iterations = 3
-       .type = int
-       .help = Iterations of solvent fraction estimation. Used for ID of \
-               solvent content in boxed maps.
-       .short_caption = Solvent fraction iterations
-       .style = hidden
-
-     molecular_mass = None
-       .type = float
-       .help = Molecular mass of molecule in Da. Used as alternative method \
-                 of specifying solvent content.
-       .short_caption = Molecular mass in Da
-
-      ncs_copies = None
-        .type = int
-        .help = You can specify ncs copies and seq file to define solvent \
-            content
-        .short_caption = NCS copies
-
-     wang_radius = None
-       .type = float
-       .help = Wang radius for solvent identification. \
-           Default is 1.5* resolution
-       .short_caption = Wang radius
-
-     buffer_radius = None
-       .type = float
-       .help = Buffer radius for mask smoothing. \
-           Default is resolution
-       .short_caption = Buffer radius
-
-     pseudo_likelihood = None
-       .type = bool
-       .help = Use pseudo-likelihood method for half-map sharpening. \
-               (In development)
-       .short_caption = Pseudo-likelihood
-       .style = hidden
-
-  }
-
-  map_modification
-    .style = menu_item auto_align
-  {
+map_modification_phil_str = """
 
      b_iso = None
        .type = float
@@ -598,6 +410,7 @@ master_phil = iotbx.phil.parse("""
         .type = int
         .short_caption = Resolution bins
         .help = Number of resolution bins for sharpening. Default is 20.
+        .expert_level = 1
 
      regions_to_keep = None
        .type = int
@@ -628,8 +441,207 @@ master_phil = iotbx.phil.parse("""
         .help = b_sol value for model map calculation. IGNORED (Not applied)
         .short_caption = b_sol IGNORED
         .style = hidden
+    """
+
+output_files = """
+
+    shifted_map_file = shifted_map.ccp4
+      .type = str
+      .help = Input map file shifted to new origin.
+      .short_caption = Shifted map file
+      .style = new_file
+
+    sharpened_map_file = None
+      .type = str
+      .help = Sharpened input map file. In the same location as input map.
+      .short_caption = Sharpened map file
+      .input_size = 400
+      .style = new_file
+      .expert_level = 1
+
+    shifted_sharpened_map_file = None
+      .type = str
+      .help = Input map file shifted to place origin at 0,0,0 and sharpened.
+      .short_caption = Shifted sharpened map file
+      .input_size = 400
+      .style = new_file
+
+    sharpened_map_coeffs_file = None
+      .type = str
+      .help = Sharpened input map \
+              (shifted to new origin if original origin was not 0,0,0), \
+              written out as map coefficients
+      .short_caption = Sharpened map coeffs file
+      .input_size = 400
+      .style = new_file
+
+    output_weight_map_pickle_file = weight_map_pickle_file.pkl
+       .type = path
+       .short_caption = Output weight map pickle file
+       .help = Output weight map pickle file
+       .style = new_file
+
+    output_directory =  None
+      .type = path
+      .help = Directory where output files are to be written \
+                applied.
+      .short_caption = Output directory
+      .style = new_file directory
+"""
+
+crystal_info = """
+     is_crystal = None
+       .type = bool
+       .short_caption = Is a crystal
+       .help = Defines whether this is a crystal (or cryo-EM).\
+                Default is True if use_sg_symmetry=True and False otherwise.
+
+     resolution = None
+       .type = float
+       .short_caption = Resolution
+       .help = Optional nominal resolution of the map.
+       .style = resolution
+       .expert_level = 1
+
+
+     solvent_content = None
+       .type = float
+       .help = Optional solvent fraction of the cell.
+       .short_caption = Solvent content
+
+     solvent_content_iterations = 3
+       .type = int
+       .help = Iterations of solvent fraction estimation. Used for ID of \
+               solvent content in boxed maps.
+       .short_caption = Solvent fraction iterations
+       .style = hidden
+
+     molecular_mass = None
+       .type = float
+       .help = Molecular mass of molecule in Da. Used as alternative method \
+                 of specifying solvent content.
+       .short_caption = Molecular mass in Da
+
+      ncs_copies = None
+        .type = int
+        .help = You can specify ncs copies and seq file to define solvent \
+            content
+        .short_caption = NCS copies
+
+     wang_radius = None
+       .type = float
+       .help = Wang radius for solvent identification. \
+           Default is 1.5* resolution
+       .short_caption = Wang radius
+
+     buffer_radius = None
+       .type = float
+       .help = Buffer radius for mask smoothing. \
+           Default is resolution
+       .short_caption = Buffer radius
+
+     pseudo_likelihood = None
+       .type = bool
+       .help = Use pseudo-likelihood method for half-map sharpening. \
+               (In development)
+       .short_caption = Pseudo-likelihood
+       .style = hidden
+"""
+
+master_phil = iotbx.phil.parse("""
+
+  input_files
+    .style = menu_item auto_align
+  {
+
+    map_file = None
+      .type = path
+      .help = File with CCP4-style map
+      .short_caption = Map file
+      .style = file_type:ccp4_map bold input_file
+
+    half_map_file = None
+      .type = path
+      .multiple = True
+      .short_caption = Half map
+      .style = file_type:ccp4_map bold input_file
+      .help = Half map (two should be supplied) for FSC calculation. Must \
+               have grid identical to map_file
+
+    external_map_file = None
+      .type = path
+      .short_caption = External map
+      .style = file_type:ccp4_map bold input_file
+      .help = External map to be used to scale map_file (power vs resolution\
+              will be matched)
+
+    map_coeffs_file = None
+      .type = path
+      .help = Optional file with map coefficients
+      .short_caption = Map coefficients
+      .style = bold file_type:hkl input_file process_hkl \
+        child:map_labels:map_coeffs_labels \
+        child:space_group:space_group child:unit_cell:unit_cell
+
+    map_coeffs_labels = None
+      .type = str
+      .input_size = 160
+      .help = Optional label specifying which columns of of map coefficients \
+          to use
+      .short_caption = Map coeffs label
+      .style = renderer:draw_map_arrays_widget
+
+    pdb_file = None
+      .type = path
+      .help = If a model is supplied, the map will be adjusted to \
+                maximize map-model correlation.  This can be used \
+                to improve a map in regions where no model is yet \
+                built.
+      .style = file_type:pdb input_file
+      .short_caption = Model file (optional)
+
+    ncs_file = None
+      .type = path
+      .help = File with NCS information (typically point-group NCS with \
+               the center specified). Typically in  PDB format. \
+              Can also be a .ncs_spec file from phenix. \
+              Created automatically if symmetry is specified.
+      .short_caption = NCS info file
+
+    seq_file = None
+       .type = path
+       .short_caption = Sequence file
+       .style = file_type:seq input_file
+       .help = Sequence file (unique chains only,  \
+               1-letter code, chains separated by \
+               blank line or greater-than sign.)  \
+               Can have chains that are DNA/RNA/protein and\
+               all can be present in one file.
+
+    input_weight_map_pickle_file = None
+      .type = path
+      .short_caption = Input weight map pickle file
+      .help = Weight map pickle file
+
   }
 
+  output_files
+    .style = menu_item auto_align
+  {
+   %s
+  }
+
+  crystal_info
+    .style = menu_item auto_align
+  {
+   %s
+  }
+
+  map_modification {
+    %s
+  }
+
+
    control
      .style = menu_item auto_align
    {
@@ -676,7 +688,8 @@ master_phil = iotbx.phil.parse("""
     .style = output_dir
   }
 
-""", process_includes=True)
+""" %(output_files, crystal_info, map_modification_phil_str),
+  process_includes=True)
 master_params = master_phil
 
 def get_params(args,out=sys.stdout):
@@ -777,21 +790,20 @@ def get_map_coeffs_from_file(
       if not map_coeffs_labels or labels==map_coeffs_labels:  # take it
          return ma
 
-def map_inside_cell(pdb_inp,crystal_symmetry=None):
-  ph=pdb_inp.construct_hierarchy()
-  pa=ph.atoms()
+def map_inside_cell(pdb_hierarchy,crystal_symmetry=None):
+  pa=pdb_hierarchy.atoms()
   sites_cart=pa.extract_xyz()
   from cctbx.maptbx.segment_and_split_map import move_xyz_inside_cell
   new_sites_cart=move_xyz_inside_cell(xyz_cart=sites_cart,
      crystal_symmetry=crystal_symmetry)
   pa.set_xyz(new_sites_cart)
-  return ph.as_pdb_input()
+  return pdb_hierarchy
 
 
 def get_map_and_model(params=None,
     map_data=None,
     crystal_symmetry=None,
-    pdb_inp=None,
+    pdb_hierarchy=None,
     ncs_obj=None,
     half_map_data_list=None,
     map_coords_inside_cell=True,
@@ -859,9 +871,9 @@ def get_map_and_model(params=None,
 
   if params.input_files.external_map_file and not \
       params.map_modification.auto_sharpen_methods==['external_map_sharpening']:
-    raise Sorry("Please specify external_map_file and "+
-        "auto_sharpen_methods=external_map_sharpening or"+
-         " neither")
+    raise Sorry("For external map sharpening, please do not set any other "+
+        "options in 'Sharpening methods' (options set: %s)" %(
+      ", ".join(params.map_modification.auto_sharpen_methods)))
 
 
   if params.map_modification.auto_sharpen_methods==['external_map_sharpening']:
@@ -902,7 +914,8 @@ def get_map_and_model(params=None,
       half_map_data_list.append(half_map_data)
 
   if params.crystal_info.resolution is None:
-    raise Sorry("Need resolution if map is supplied")
+    raise Sorry("Need resolution for b-sharpening if "+
+       "map is supplied and no model is supplied")
 
   if params.crystal_info.resolution >= 10:
     print("\n** WARNING: auto_sharpen is designed for maps at a "+\
@@ -910,26 +923,27 @@ def get_map_and_model(params=None,
       "poor at %7.0f A" %(params.crystal_info.resolution), file=out)
 
 
-  if params.input_files.pdb_file and not pdb_inp: # get model
+  if params.input_files.pdb_file and not pdb_hierarchy: # get model
     model_file=params.input_files.pdb_file
     if not os.path.isfile(model_file):
       raise Sorry("Missing the model file: %s" %(model_file))
-    pdb_inp=iotbx.pdb.input(file_name=model_file)
-  if pdb_inp: # XXX added 2019-05-05
+    from iotbx.pdb.utils import get_pdb_hierarchy
+    pdb_hierarchy= get_pdb_hierarchy(file_name = model_file)
+  if pdb_hierarchy: # XXX added 2019-05-05
     if origin_frac != (0,0,0):
       print("Shifting model by %s" %(str(origin_frac)), file=out)
       from cctbx.maptbx.segment_and_split_map import \
          apply_shift_to_pdb_hierarchy
       origin_shift=crystal_symmetry.unit_cell().orthogonalize(
          (-origin_frac[0],-origin_frac[1],-origin_frac[2]))
-      pdb_inp=apply_shift_to_pdb_hierarchy(
+      pdb_hierarchy=apply_shift_to_pdb_hierarchy(
        origin_shift=origin_shift,
        crystal_symmetry=crystal_symmetry,
-       pdb_hierarchy=pdb_inp.construct_hierarchy(),
-       out=out).as_pdb_input()
+       pdb_hierarchy=pdb_hierarchy,
+       out=out)
     if map_coords_inside_cell:
       # put inside (0,1)
-      pdb_inp=map_inside_cell(pdb_inp,crystal_symmetry=crystal_symmetry)
+      pdb_hierarchy=map_inside_cell(pdb_hierarchy,crystal_symmetry=crystal_symmetry)
 
   if params.input_files.ncs_file and not ncs_obj: # NCS
     from cctbx.maptbx.segment_and_split_map import get_ncs
@@ -943,10 +957,12 @@ def get_map_and_model(params=None,
        coordinate_offset=matrix.col(origin_shift))
 
   if get_map_labels:
-    return pdb_inp,map_data,half_map_data_list,ncs_obj,crystal_symmetry,acc,\
+    return pdb_hierarchy,\
+       map_data,half_map_data_list,ncs_obj,crystal_symmetry,acc,\
        original_crystal_symmetry,original_unit_cell_grid,map_labels
   else:
-    return pdb_inp,map_data,half_map_data_list,ncs_obj,crystal_symmetry,acc,\
+    return pdb_hierarchy,\
+      map_data,half_map_data_list,ncs_obj,crystal_symmetry,acc,\
        original_crystal_symmetry,original_unit_cell_grid
 
 
@@ -954,7 +970,7 @@ def run(args=None,params=None,
     map_data=None,crystal_symmetry=None,
     wrapping = None,
     write_output_files=True,
-    pdb_inp=None,
+    pdb_hierarchy=None,
     ncs_obj=None,
     return_map_data_only=False,
     return_unshifted_map=False,
@@ -971,12 +987,12 @@ def run(args=None,params=None,
 
   # get map_data and crystal_symmetry
 
-  pdb_inp,map_data,half_map_data_list,ncs_obj,crystal_symmetry,acc,\
+  pdb_hierarchy,map_data,half_map_data_list,ncs_obj,crystal_symmetry,acc,\
        original_crystal_symmetry,original_unit_cell_grid,map_labels=\
         get_map_and_model(
      map_data=map_data,
      half_map_data_list=half_map_data_list,
-     pdb_inp=pdb_inp,
+     pdb_hierarchy=pdb_hierarchy,
      ncs_obj=ncs_obj,
      map_coords_inside_cell=False,
      crystal_symmetry=crystal_symmetry,
@@ -1075,7 +1091,7 @@ def run(args=None,params=None,
            params.map_modification.resolution_dependent_b,
         normalize_amplitudes_in_resdep=\
            params.map_modification.normalize_amplitudes_in_resdep,
-        pdb_inp=pdb_inp,
+        pdb_hierarchy=pdb_hierarchy,
         ncs_obj=ncs_obj,
         rmsd=params.map_modification.rmsd,
         rmsd_resolution_factor=params.map_modification.rmsd_resolution_factor,
@@ -1109,6 +1125,8 @@ def run(args=None,params=None,
   if acc is not None:  # offset the map to match original if possible
     offset_map_data.reshape(acc)
 
+  if write_output_files and (not params.output_files.sharpened_map_file):
+    params.output_files.sharpened_map_file = 'sharpened_map.ccp4'
   if write_output_files and params.output_files.sharpened_map_file and \
       offset_map_data:
     output_map_file=os.path.join(params.output_files.output_directory,
@@ -1146,6 +1164,8 @@ def run(args=None,params=None,
     print("\nWrote sharpened map (origin at %s)\nto %s" %(
      str(new_map_data.origin()),output_map_file), file=out)
 
+  if write_output_files and (not params.output_files.sharpened_map_coeffs_file):
+     params.output_files.sharpened_map_coeffs_file = 'sharpened_map_coeffs.mtz'
   if write_output_files and params.output_files.sharpened_map_coeffs_file and \
       new_map_coeffs:
     output_map_coeffs_file=os.path.join(params.output_files.output_directory,
