@@ -580,6 +580,11 @@ class structure(crystal.special_position_settings):
                    .n_independent_params()] += 1
     return result
 
+  def get_scattering_table(self):
+    if not self._scattering_type_registry:
+      return None
+    return self._scattering_type_registry.last_table()
+
   def guess_scattering_type_neutron(self):
     ac,bc,cc = 0,0,0
     result = False
