@@ -1,7 +1,11 @@
 from __future__ import absolute_import, division, print_function
-import boost_adaptbx.boost.python as bp
-ext = bp.import_ext("gltbx_gl_ext")
-from gltbx_gl_ext import *
+try:
+  import OpenGL  # implicit import
+  from OpenGL.GL import *
+except ImportError:
+  import boost_adaptbx.boost.python as bp
+  ext = bp.import_ext("gltbx_gl_ext")
+  from gltbx_gl_ext import *
 
 def __function_taking_transposed_matrix(f):
   def wrapper(m):
