@@ -651,7 +651,7 @@ def parallel_map(
 
 
 
-def multi_core_run( myfunction, argstuples, nproc ):
+def multi_core_run( myfunction, argstuples, nproc, keep_input_order=False ):
   """
   Run myfunction on many cpu cores using multiprocessing.
   A simplified version of parallel_map() above
@@ -659,6 +659,8 @@ def multi_core_run( myfunction, argstuples, nproc ):
   myfunction: name of the function to be parallelised,
   argstuples: list of tuples of associated input arguments,
   nproc: number of cores to run on.
+  keep_input_order: if True, the function returns once all child processes have completed and
+                    results are in same order as the argstuples elements
 
   Both myfunction and its input arguments must be pickleable.
 
@@ -721,7 +723,7 @@ def multi_core_run( myfunction, argstuples, nproc ):
   pfi = parallel_for.iterator(
       calculations = ( ( myfunction, args, {} ) for args in argstuples ),
       manager = manager,
-      keep_input_order = False,
+      keep_input_order = keep_input_order,
       )
 
   for i, ( calc, res ) in enumerate(pfi):
@@ -775,7 +777,7 @@ def run_parallel(
    kw_list=None,           # list of kw dictionaries for target_function
    preserve_order=True,
    break_condition = None,
-   try_single_processor_on_failure = False,
+   try_single_processor_on_failure = True,
    ):
 
   '''
@@ -785,40 +787,16 @@ def run_parallel(
   '''
   n=len(kw_list)  # number of jobs to run, one per kw dict
 
-  if nproc==1 or n<=1: # just run it for each case in list, no multiprocessing
+  # Two ways to run:  directly or with parallel_map
+
+  def run_directly(kw_list, target_function, n):
     results=[]
     ra=run_anything(kw_list=kw_list,target_function=target_function)
     for i in range(n):
       results.append(ra(i))
-  elif try_single_processor_on_failure:
-    try:  # Try as is, then use nproc=1 if it fails for any reason
-      return run_parallel(
-         method=method,
-         qsub_command=qsub_command,
-         nproc=nproc,
-         target_function=target_function,
-         kw_list=kw_list,
-         preserve_order=preserve_order,
-         break_condition=break_condition)
-    except Exception as e:
-      return run_parallel(
-         method=method,
-         qsub_command=qsub_command,
-         nproc=1,
-         target_function=target_function,
-         kw_list=kw_list,
-         preserve_order=preserve_order,
-         break_condition=break_condition)
+    return results
 
-
-  elif 0:  #(method == "multiprocessing") and (sys.platform != "win32"):
-    # XXX Can crash 2015-10-13 TT so don't use it
-    from libtbx.easy_mp import  pool_map
-    results = pool_map(
-      func=run_anything(target_function=target_function,kw_list=kw_list),
-      iterable=range(n),
-      processes=nproc)
-  else :
+  def run_with_parallel_map(kw_list, target_function, n):
     from libtbx.easy_mp import parallel_map
     results=parallel_map(
       func=run_anything(target_function=target_function,kw_list=kw_list),
@@ -832,6 +810,22 @@ def run_parallel(
       use_manager=True,  #  Always use manager 2015-10-13 TT (sys.platform == "win32"))
       preserve_order=preserve_order,
       break_condition = break_condition)
+    return results
+
+  # Now actually run
+
+  if nproc==1 or n<=1: # just run it for each case in list, no multiprocessing
+    results = run_directly(kw_list, target_function, n)
+
+  elif try_single_processor_on_failure:
+    try:  # Try as is, then use nproc=1 if it fails for any reason
+      results = run_with_parallel_map(kw_list, target_function, n)
+    except Exception as e:
+      results = run_directly(kw_list, target_function, n)
+
+  else : # standard run, run outside of a try
+    results = run_with_parallel_map(kw_list, target_function, n)
+
   return results
 
 #  -------  END OF SIMPLE INTERFACE TO MULTIPROCESSING -------------
@@ -1013,7 +1007,7 @@ def run_jobs_with_large_fixed_objects(
        multiprocessing_method = 'multiprocessing',  # how to run
        qsub_command='qsub',       # queue command,
        break_condition = None,
-       try_single_processor_on_failure = False,
+       try_single_processor_on_failure = True,
        log = sys.stdout):
   '''
 
