@@ -6,6 +6,7 @@ from scitbx.array_family import flex
 from mmtbx.geometry_restraints import base_qm_manager
 
 import libtbx.load_env
+from libtbx import Auto
 
 from mmtbx.geometry_restraints.base_qm_manager import get_internal_coordinate_value
 
@@ -34,11 +35,22 @@ class mopac_manager(base_qm_manager.base_qm_manager):
       nproc_str=''
     else:
       nproc_str='THREADS=%s' % self.nproc
-    outl = '%s %s %s %s DISP \n%s\n\n' % (
+    multiplicity_str=''
+    if self.multiplicity not in [None, Auto]:
+      multiplicity_str=[None,
+                        'singlet', # - 0 unpaired electrons
+                        'doublet', # - 1 unpaired electrons
+                        'triplet', # - 2 unpaired electrons
+                        'quartet', # - 3 unpaired electrons
+                        'quintet', # - 4 unpaired electrons
+                        'sextet', # - 5 unpaired electrons
+                        ][self.multiplicity]
+    outl = '%s %s %s %s DISP %s\n%s\n\n' % (
      self.method,
      self.basis_set,
      self.solvent_model,
      'CHARGE=%s %s' % (self.charge, nproc_str),
+     multiplicity_str,
      self.preamble,
      )
     return outl
@@ -120,11 +132,12 @@ class mopac_manager(base_qm_manager.base_qm_manager):
   def get_input_filename(self):
     return 'mopac_%s.mop' % self.preamble
 
-  def read_xyz_output(self):
+  def read_xyz_output(self, verbose=False):
     filename = self.get_coordinate_filename()
     filename = filename.replace('.arc', '.out')
     if not os.path.exists(filename):
       raise Sorry('QM output filename not found: %s' % filename)
+    if verbose: print('reading %s' % filename)
     f=open(filename, 'r')
     lines = f.read()
     del f
@@ -179,6 +192,36 @@ class mopac_manager(base_qm_manager.base_qm_manager):
         break
     return self.charge
 
+  def validate_atomic_charges(self, filename=None):
+    '''
+                 NET ATOMIC CHARGES AND DIPOLE CONTRIBUTIONS
+
+  ATOM NO.   TYPE          CHARGE      No. of ELECS.   s-Pop       p-Pop
+    1          C          -0.691089        4.6911     1.10997     3.58112
+    2          C           0.963519        3.0365     1.15413     1.88235
+    3          O          -0.111514        6.1115     1.65968     4.45183
+    4          H           0.405761        0.5942     0.59424
+    5          H           0.399617        0.6004     0.60038
+    6          H           0.404684        0.5953     0.59532
+    7          H           1.000000        0.0000     0.00000
+    8          H           1.000000        0.0000     0.00000
+    9          H           0.629022        0.3710     0.37098
+ DIPOLE           X         Y         Z       TOTAL
+ POINT-CHG.    29.803  -147.398  -116.121   189.996
+ HYBRID         0.786     0.431     0.475     1.015
+ SUM           30.590  -146.966  -115.646   189.496'''
+    lines = self.get_lines(filename=filename)
+    reading=False
+    for line in lines.splitlines():
+      if reading:
+        print(line)
+        assert 0
+      if line.find('ATOM NO.   TYPE          CHARGE      No. of ELECS.')>-1:
+        reading=True
+
+  def validate_calculation(self):
+    self.validate_atomic_charges()
+
   def read_gradients(self, filename=None):
     lines = self.get_lines(filename=filename)
     print(lines)
