@@ -488,31 +488,21 @@ class _mtriage(object):
 
   def _compute_half_map_fsc(self):
     if(self.map_data_1 is not None):
-      bin_width=100
-      if self.n_bins:
-        bin_width=max(bin_width,int(0.5+self.f_map_1.size()/self.n_bins))
       self.fsc_curve = self.f_map_1.d_min_from_fsc(
-        other = self.f_map_2, bin_width=bin_width, fsc_cutoff=0.143)
+        other = self.f_map_2, fsc_cutoff=0.143)
       self.d_fsc = self.fsc_curve.d_min
 
   def _compute_half_map_fsc_05(self):
     if(not self.params.compute.d_fsc_half_map_05): return
     if(self.map_data_1 is not None):
-      bin_width=100
-      if self.n_bins:
-        bin_width=max(bin_width,int(0.5+self.f_map_1.size()/self.n_bins))
       self.fsc_curve_05 = self.f_map_1.d_min_from_fsc(
-        other = self.f_map_2, bin_width=bin_width, fsc_cutoff=0.5)
+        other = self.f_map_2, fsc_cutoff=0.5)
       self.d_fsc_05 = self.fsc_curve_05.d_min
 
   def _compute_fsc_curve_model(self):
     if(not self.params.compute.fsc_curve_model): return
     if(self.xray_structure is not None):
-      bin_width=100
-      if self.n_bins:
-        bin_width=max(bin_width,int(0.5+self.f_calc.size()/self.n_bins))
-      self.fsc_curve_model = self.f_calc.fsc(
-        other=self.f_map, bin_width=bin_width)
+      self.fsc_curve_model = self.f_calc.fsc(other=self.f_map)
 
   def _compute_f_fsc_model_0(self):
     if(not self.params.compute.d_fsc_model_0): return
