@@ -465,14 +465,14 @@ def getExtraAtomInfo(model, bondedNeighborLists, useNeutronDistances = False, pr
               else:
                 fullName = (chain.id + ' ' + a.parent().resname.strip() + ' ' +
                   str(a.parent().parent().resseq_as_int()) + ' ' + a.name.strip())
-                raise Sorry("Could not find atom info for "+fullName+
-                  "(perhaps interpretation was not run on the model?)\n")
+                raise Sorry("Unrecognized specific H bond type for "+fullName+", got "+hb_type+"\n")
 
             except Exception as e:
               fullName = (chain.id + ' ' + a.parent().resname.strip() + ' ' +
                 str(a.parent().parent().resseq_as_int()) + ' ' + a.name.strip())
               raise Sorry("Could not find atom info for "+fullName+
-                " (perhaps interpretation was not run on the model?)\n")
+                " (perhaps interpretation was not run on the model?)\n"+
+                "  Exception: "+str(e))
 
   return getExtraAtomInfoReturn(extras, warnings)
 
