@@ -36,7 +36,7 @@ import tempfile
 from iotbx.data_manager import DataManager
 import csv
 
-version = "2.6.0"
+version = "2.7.0"
 
 master_phil_str = '''
 approach = *add remove
@@ -1033,8 +1033,12 @@ NOTES:
       for res in insufficient_restraints[1:]:
         bad += "," + res
       raise Sorry("Insufficient restraints were found for the following atoms:"+bad)
+
     self.model = reduce_add_h_obj.get_model()
 
+    if not self.model.has_hd():
+      raise Sorry("It was not possible to place any H atoms. Is this a single atom model?")
+
 # ------------------------------------------------------------------------------
 
   def _ReinterpretModel(self, make_restraints=True):
@@ -1186,9 +1190,7 @@ NOTES:
 
     # Fix up bogus unit cell when it occurs by checking crystal symmetry.
     # @todo reduce_hydrogens.py:run() says: TODO temporary fix until the code is moved to model class
-    cs = self.model.crystal_symmetry()
-    if (cs is None) or (cs.unit_cell() is None):
-      self.model = shift_and_box_model(model = self.model, shift_model=False)
+    self.model = shift_and_box_model(model = self.model, shift_model=False)
 
     # If we've been asked to only to a single model index from the file, strip the model down to
     # only that index.
