@@ -149,10 +149,14 @@ general_tests = [
   "$D/regression/tst_altloc_remediate.py",
   "$D/hydrogens/build_hydrogens.py",
   "$D/hydrogens/tst.py",
+  # Reduce 2 - hydrogenate
   "$D/hydrogens/tst_add_hydrogen_1.py",
   "$D/hydrogens/tst_add_hydrogen_2.py",
   "$D/hydrogens/tst_add_hydrogen_3.py",
   "$D/hydrogens/tst_add_hydrogen_4.py",
+  "$D/hydrogens/tst_add_hydrogen_5.py",
+  "$D/hydrogens/tst_add_hydrogen_6.py",
+  "$D/hydrogens/tst_add_hydrogen_7.py",
   #"$D/hydrogens/tst_add_hydrogen_time.py",
   "$D/hydrogens/tst_validate_H.py",
   "$D/hydrogens/tst_connectivity.py",
@@ -218,7 +222,6 @@ general_tests = [
   "$D/regression/tst_regularize_from_pdb_cif.py",
   "$D/regression/tst_find_ncs.py",
   "$D/regression/tst_minimize_chain.py",
-  "$D/regression/tst_minimize_chain_cif.py",
   "$D/regression/tst_sequence_validation.py",
   "$D/regression/tst_prune_model.py",
   "$D/regression/tst_real_space_correlation.py",
@@ -261,6 +264,7 @@ general_tests = [
   "$D/regression/tst_anomalous_substructure.py",
   #
   "$D/regression/tst_fmodel_no_cryst1.py",
+  "$D/regression/tst_fmodel_and_dm.py",
   "$D/regression/tst_fmodel_misc.py",
   "$D/regression/tst_isomorphous_difference_misc.py",
   "$D/regression/tst_dynamics_cli.py",
@@ -380,6 +384,7 @@ general_tests = [
   #
   "$D/nci/tst_hbond.py",
   "$D/wwpdb/tst_rcsb_web_services.py",
+  "$D/wwpdb/tst_rcsb_entry_request.py",
   "$D/regression/command_line/tst_find_residue_in_pdb.py",
   "$D/monomer_library/tst_all_cif_files.py",
   "$D/refinement/tst_misc.py",
@@ -404,8 +409,10 @@ general_tests = [
   "$D/regression/fix_cablam/tst_single_outliers_surroundings.py",
   "$D/regression/fix_cablam/tst_one_resid_rotation.py",
   "$D/regression/fix_cablam/tst_insertion_codes.py",
-  #
+  # Tests involving scattering table
   "$D/regression/tst_scattering_type_registry.py",
+  "$D/regression/tst_scattering_table.py",
+  #
   "$D/atomic_environment_vectors/tst.py",
   #
   "$D/building/ligands/tst_00.py",
