@@ -36,11 +36,11 @@ def exercise():
   homologs = rcsb_web_services.sequence_search(lysozyme, d_max=2.0)
   assert (len(homologs) > 500)
   atp_binding = rcsb_web_services.chemical_id_search("ATP", protein_only=True)
-  # print("len(atp_binding)", len(atp_binding)) # 1314
-  assert (len(atp_binding) > 650)
+  # print("len(atp_binding)", len(atp_binding), atp_binding) # 1389
+  assert (len(atp_binding) > 1000)
   atp_binding = rcsb_web_services.chemical_id_search("ATP", xray_only=True, protein_only=True)
-  # print("len(atp_binding)", len(atp_binding)) # 1314
-  assert (len(atp_binding) > 650)
+  # print("len(atp_binding)", len(atp_binding)) # 1389
+  assert (len(atp_binding) > 1000)
   report = rcsb_web_services.get_high_resolution_for_structures(atp_binding)
   assert (len(report) == len(atp_binding)) and (len(report[0]) == 2)
   # print (report)
@@ -90,7 +90,16 @@ def exercise_3():
   r = rcsb_web_services.post_query(d_min=5)
   assert len(r) > 1
   r = rcsb_web_services.post_query(sort_by_resolution=True)
-  assert len(r) > 1
+  assert len(r) > 180000
+  r = rcsb_web_services.post_query(clashscore_range=(1,5))
+  print('n clashscore filter:', len(r))
+  assert len(r) > 80000
+  r = rcsb_web_services.post_query(rama_outliers_range=(1,2))
+  print('n rama filter:', len(r))
+  assert len(r) > 10000
+  r = rcsb_web_services.post_query(rota_outliers_range=(0,5))
+  print('n rota filter:', len(r))
+  assert len(r) > 135000
 
 def exercise_get_emdb_id():
   emdb_ids = rcsb_web_services.get_emdb_id_for_pdb_id('8wcc')
