@@ -2,6 +2,7 @@ from __future__ import absolute_import, division, print_function
 import boost_adaptbx.boost.python as bp
 import cctbx.uctbx # possibly implicit
 ext = bp.import_ext("simtbx_nanoBragg_ext")
+from libtbx.phil import parse
 from scitbx.array_family import flex
 from simtbx_nanoBragg_ext import *
 from scitbx.matrix import col, sqr
@@ -14,7 +15,11 @@ from dxtbx.model.experiment_list import Experiment, ExperimentList
 from dxtbx.model import CrystalFactory
 from dxtbx.model import BeamFactory
 from dxtbx.model import DetectorFactory
-from dxtbx.format import cbf_writer
+from dxtbx.format.Format import Format
+from dxtbx.format import cbf_writer, nxmx_writer
+from cctbx import sgtbx
+from cctbx.sgtbx.literal_description import literal_description
+import numpy as np
 
 
 @bp.inject_into(ext.nanoBragg)
@@ -31,14 +36,19 @@ class _():
       mset = set(crystal_symmetry=cs, anomalous_flag=True, indices=indices)
       return array(mset, data=data).set_observation_type_xray_amplitude()
 
-  def set_mosaic_blocks_sym(self, crystal, reference_symbol, orig_mos_domains):
+  def set_mosaic_blocks_sym(self, crystal, reference_symbol, orig_mos_domains, refining_eta=False):
     """
     hijack the mosaic blocks to symmetrize F_latt for P3/P6 space groups
     Will extend mosaic blocks by up to a factor of 3
-    :param crystal:  dxtbx crystal model in the original setting (reference)
+    :param crystal:  dxtbx crystal model, preferably in the original setting (reference)
     :param symbol: space group loopk symbol e.g. P6522
-    :param orig_mos_domains: int number of mosaic blocks before adding symmetry pairs
+    :param orig_mos_domains: int number of mosaic blocks before adding 3-fold mosaic blocks
+    :param refining_eta: bool, if using diffBragg to refine eta, the umat derivative mats should also be updated
     """
+    if refining_eta:
+      # TODO, fix this case, see diffBragg.cpp, method get_mosaic_blocks_prime
+      assert not self.has_anisotropic_spread
+
     sgi = sgtbx.space_group_info(reference_symbol)
     cb_op = sgi.change_of_basis_op_to_primitive_setting()
     # TODO? use internal nanoBragg parameters to get the p1 a,b,c vectors,
@@ -50,15 +60,24 @@ class _():
 
     # this should be equivalent to column matrix of real space vectors
     a,b,c = crystal_reference.get_real_space_vectors()
-    assert sqr(a+b+c).transpose()==A
+    assert np.allclose(sqr(a+b+c).transpose().elems , A.elems)
 
     # get the originally set mosaic blocks
     mos_blocks = self.get_mosaic_blocks()[:orig_mos_domains]
+    mos_blocks_prime = None
+    if refining_eta:
+      mos_blocks_prime = self.get_mosaic_blocks_prime()[:orig_mos_domains]
 
     # new list of mosaic blocks
     new_mos_blocks = flex.mat3_double()
     new_mos_blocks.extend(mos_blocks)
 
+    # eta deriv matrices
+    new_mos_blocks_prime = None
+    if mos_blocks_prime is not None:
+      new_mos_blocks_prime = flex.mat3_double()
+      new_mos_blocks_prime.extend(mos_blocks_prime)
+
     # loop over all laue group 3-fold operations
     ops = sgi.group().build_derived_laue_group().all_ops()
     for op in ops:
@@ -71,11 +90,16 @@ class _():
         Rcryst = A*R*A.inverse()
         # this will left-multiply the real space amatrix in nanoBragg / diffBragg
         new_mos_blocks.extend(flex.mat3_double([sqr(U)*Rcryst for U in mos_blocks]))
+        if new_mos_blocks_prime is not None:
+          #TODO does Umat_prime need to also be multiplied by Rcryst ?
+          new_mos_blocks_prime.extend(flex.mat3_double([sqr(U) for U in mos_blocks_prime]))
 
     self.set_mosaic_blocks(new_mos_blocks)
+    if new_mos_blocks_prime is not None:
+      self.set_mosaic_blocks_prime(new_mos_blocks_prime)
+
     # if using diffBragg, we must also call:
     if self.vectorize_umats is not None:
-      print("vectorizing Umats")
       self.vectorize_umats()
 
     # need to update nanoBragg mos_spread_deg so it actually runs through the mosaic domains
@@ -201,19 +225,19 @@ class _():
     det_descr = {'panels':
                    [{'fast_axis': fdet,
                      'slow_axis': sdet,
-                     'gain': self.quantum_gain,
+                     'gain': 1, # this should always be 1 for simulations. If you ran add_noise then quantum gain was multiplied
                      'identifier': '',
                      'image_size': im_shape,
                      'mask': [],
-                     'material': '',  # TODO
+                     'material': 'Si',
                      'mu': 0.0,  # TODO
                      'name': 'Panel',
                      'origin': origin,
                      'pedestal': 0.0,
                      'pixel_size': (pixsize, pixsize),
                      'px_mm_strategy': {'type': 'SimplePxMmStrategy'},
-                     'raw_image_offset': (0, 0),  # TODO
-                     'thickness': 0.0,  # TODO
+                     'raw_image_offset': (0, 0),
+                     'thickness': 0.00001,  # TODO
                      'trusted_range': (-1e3, 1e10),  # TODO
                      'type': ''}]}
     detector = DetectorFactory.from_dict(det_descr)
@@ -221,10 +245,17 @@ class _():
 
   @property
   def imageset(self):
-    format_class = FormatBraggInMemory(self.raw_pixels)
+    if self.cbf_int:
+      raw_pix = self.raw_pixels.as_numpy_array()
+      raw_pix = flex.int(raw_pix.astype(np.int32))
+    else:
+      raw_pix = self.raw_pixels
+
+    format_class = FormatBraggInMemory(raw_pix)
     reader = MemReaderNamedPath("virtual_Bragg_path", [format_class])
     reader.format_class = FormatBraggInMemory
-    imageset_data = ImageSetData(reader, None)
+    imageset_data = ImageSetData(reader, None, vendor="", params={'raw_pixels': raw_pix},
+                                 format=FormatBraggInMemory)
     imageset = ImageSet(imageset_data)
     imageset.set_beam(self.beam)
     imageset.set_detector(self.detector)
@@ -267,8 +298,46 @@ class _():
 
     return explist
 
-  def to_cbf(self, cbf_filename, toggle_conventions=False, intfile_scale=1.0):
+  def to_cbf(self, cbf_filename, toggle_conventions=False, intfile_scale=1.0, cbf_int=False):
     """write a CBF-format image file to disk from the raw pixel array
+    intfile_scale: multiplicative factor applied to raw pixels before output
+         intfile_scale > 0 : value of the multiplicative factor
+         intfile_scale = 1 (default): do not apply a factor
+         intfile_scale = 0 : compute a reasonable scale factor to set max pixel to 55000; given by get_intfile_scale()
+    cbf_int: boolean flag, write the cbf using 32-bit int precision
+    """
+    temp = self.cbf_int
+    self.cbf_int = cbf_int
+
+    if intfile_scale != 1.0:
+      cache_pixels = self.raw_pixels
+      if intfile_scale > 0: self.raw_pixels = self.raw_pixels * intfile_scale
+      else: self.raw_pixels = self.raw_pixels * self.get_intfile_scale()
+      # print("switch to scaled")
+
+    if toggle_conventions:
+      # switch to DIALS convention before writing CBF
+      CURRENT_CONV = self.beamcenter_convention
+      self.beamcenter_convention=DIALS
+
+    imgset = self.imageset
+    writer = cbf_writer.FullCBFWriter(imageset=imgset)
+    cbf = writer.get_cbf_handle(index=0, header_only=True)
+    data = imgset.get_raw_data(0)
+    writer.add_data_to_cbf(cbf, data=data)
+    writer.write_cbf(cbf_filename, cbf=cbf)
+
+    if toggle_conventions:
+      self.beamcenter_convention=CURRENT_CONV
+
+    if intfile_scale != 1.0:
+      self.raw_pixels = cache_pixels
+      # print("switch back to cached")
+
+    self.cbf_int = temp
+
+  def to_nexus_nxmx(self, nxmx_filename, toggle_conventions=False, intfile_scale=1.0):
+    """write a NeXus NXmx-format image file to disk from the raw pixel array
     intfile_scale: multiplicative factor applied to raw pixels before output
          intfile_scale > 0 : value of the multiplicative factor
          intfile_scale = 1 (default): do not apply a factor
@@ -285,8 +354,18 @@ class _():
       CURRENT_CONV = self.beamcenter_convention
       self.beamcenter_convention=DIALS
 
-    writer = cbf_writer.FullCBFWriter(imageset=self.imageset)
-    writer.write_cbf(cbf_filename, index=0)
+    params = nxmx_writer.phil_scope.fetch(parse("""
+    output_file=%s
+    nexus_details {
+      instrument_name=nanoBragg
+      source_name=nanoBragg
+      start_time=NA
+      end_time_estimated=NA
+      sample_name=nanoBragg
+    }
+    """%nxmx_filename)).extract()
+    writer = nxmx_writer.NXmxWriter(params)
+    writer(imageset=self.imageset)
 
     if toggle_conventions:
       self.beamcenter_convention=CURRENT_CONV
@@ -295,6 +374,22 @@ class _():
       self.raw_pixels = cache_pixels
       # print("switch back to cached")
 
+def nexus_factory(nxmx_filename):
+    params = nxmx_writer.phil_scope.fetch(parse("""
+    output_file=%s
+    nexus_details {
+      instrument_name=nanoBragg
+      source_name=nanoBragg
+      start_time=NA
+      end_time_estimated=NA
+      sample_name=nanoBragg
+    }
+    dtype=int32
+    """%nxmx_filename)).extract()
+    writer = nxmx_writer.NXmxWriter(params)
+    return writer
+
+
 def make_imageset(data, beam, detector):
   format_class = FormatBraggInMemoryMultiPanel(data)
   reader = MemReaderNamedPath("virtual_Bragg_path", [format_class])
@@ -332,7 +427,7 @@ class FormatBraggInMemoryMultiPanel:
     """dummie place holder for mask, consider using internal nanoBragg mask"""
     return self.mask
 
-class FormatBraggInMemory:
+class FormatBraggInMemory(Format):
 
   def __init__(self, raw_pixels):
     self.raw_pixels = raw_pixels
@@ -358,6 +453,10 @@ class FormatBraggInMemory:
     """dummie place holder for mask, consider using internal nanoBragg mask"""
     return self.mask,
 
+  @classmethod
+  def get_instance(Class, filename, **kwargs):
+    return Class(raw_pixels = kwargs.pop('raw_pixels'), **kwargs)
+
   #def paths(self):
   #  return ["InMemoryBraggPath"]  # TODO: CBFLib complains if no datablock path provided which comes from path
 
