@@ -5,15 +5,16 @@ __author__ = 'zeldin'
 
 
 def run(_args):
-  if _args < 2:
-    raise IOError("Must give at least one path to folder of pickles")
   import logging
   from xfel.clustering.cluster import Cluster
   FORMAT = '%(message)s'
   logging.basicConfig(level=logging.WARNING, format=FORMAT)
 
-  cluster = Cluster.from_directories(_args.folders,
-                                          'Command line visualisation')
+  if _args.paths:
+    cluster = Cluster.from_files(raw_input=_args.folders, dials=_args.dials)
+  else:
+    cluster = Cluster.from_directories(_args.folders, 'Command line visualisation', dials=_args.dials)
+
   logging.info("data imported")
   cluster.visualise_orientational_distribution()
 
@@ -24,6 +25,10 @@ if __name__ == "__main__":
   distribution of a set of integration pickles'''))
   parser.add_argument('folders', type=str, nargs='+',
                       help='One or more folers containing integration pickles.')
+  parser.add_argument('--dials', action='store_true',
+                      help='Interpret the arguments as DIALS-format pickles and jsons.')
+  parser.add_argument('--paths', action='store_true',
+                      help='Interpret the arguments as complete paths to pickles or tarred pickles, not directories.')
   args = parser.parse_args()
   result = run(args)
 
