@@ -129,7 +129,7 @@ def split_sigma_test(self, other, scale, use_binning=False, show_plot=False):
 
 def r1_factor(self, other, scale_factor=None, assume_index_matching=False,
                 use_binning=False):
-    """Get the R1 factor according to this formula
+    r"""Get the R1 factor according to this formula
 
     .. math::
        R1 = \dfrac{\sum{||F| - k|F'||}}{\sum{|F|}}
